@@ -8,7 +8,7 @@ from mcsniperpy.util import request_manager
 from mcsniperpy.util import utils as util
 from mcsniperpy.util.classes.config import BackConfig, populate_configs, Config
 from mcsniperpy.util.name_system import api_timing, namemc_timing
-
+from mcsniperpy.util import announce
 
 class Sniper:
     def __init__(self,
@@ -73,7 +73,9 @@ class Sniper:
         self.accounts = util.parse_accs(os.path.join(self.config.config['sniper'].get('init_path'), "accounts.txt"))
 
         timing_system = self.user_config.config['sniper'].get('timing_system', 'kqzz_api').lower()
-        start_auth = self.user_config.config['accounts'].getint('start_authentication', '720')
+        start_auth = self.user_config.config['accounts'].getint('start_authentication', '720') * 60
+        do_announce = self.user_config.config['announce'].getboolean('announce_snipe', 'no')
+        announce_code = self.user_config.config['announce'].getboolean('announce_code', '')
 
         if timing_system == 'kqzz_api':
             droptime = await api_timing(target, self.session)
@@ -84,14 +86,15 @@ class Sniper:
 
         req_count = self.user_config.config['sniper'].getint('snipe_requests', '3')
 
-        await self.snipe(droptime, target, offset, req_count, start_auth)
+        await self.snipe(droptime, target, offset, req_count, start_auth, do_announce, announce_code)
 
-    async def snipe(self, droptime, target, offset, req_count, start_auth):
+    async def snipe(self, droptime, target, offset, req_count, start_auth, do_announce, announce_code):
 
         authentication_coroutines = [acc.fully_authenticate(session=self.session) for acc in self.accounts]
         pre_snipe_coroutines = [acc.snipe_connect() for _ in range(req_count) for acc in self.accounts]  # For later use
 
-        time_until_authentication = 0 if time.time() > (droptime - start_auth) else (droptime - start_auth) - time.time()
+        now = time.time()
+        time_until_authentication = 0 if now > (droptime - start_auth) else (droptime - start_auth) - now
 
         self.log.debug(f'authorizing accounts in {time_until_authentication} seconds.')
 
@@ -102,7 +105,8 @@ class Sniper:
         for acc in self.accounts:
             acc.encode_snipe_data(target)
 
-        time_until_connect = 0 if time.time() > (droptime - 20) else (droptime - 20) - time.time()
+        now = time.time()
+        time_until_connect = 0 if now > (droptime - 20) else (droptime - 20) - now
 
         self.log.debug(f'Connecting in {time_until_connect} seconds.')
 
@@ -121,13 +125,20 @@ class Sniper:
                              ) for i in range(req_count) for acc in self.accounts]
         )  # Reads the responses
 
-        for is_success, email in responses:
+        for is_success, email, _ in responses:
             if is_success:
                 success_acc = util.find_acc_by_email(email, self.accounts)
                 self.log.info(f'{self.color.white}[{self.color.l_green}success{self.color.white}]{self.color.reset} '
                               f'sniped {self.target} onto {success_acc.email}')
+                if do_announce:
+                    await announce.announce(
+                        username=target,
+                        authorization=announce_code,
+                        session=self.session
+                    )
 
     def on_shutdown(self):
         if self.session.session is not None:
             asyncio.run(self.session.session.close())
-        self.log.shutdown()
+        if self.log is not None:
+            self.log.shutdown()
